@@ -5,6 +5,23 @@
  * \b Project: Kid3
  * \author Urs Fleisch
  * \date 5 Jul 2005
+ *
+ * Copyright (C) 2005-2007  Urs Fleisch
+ *
+ * This file is part of Kid3.
+ *
+ * Kid3 is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Kid3 is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DIRLIST_H
@@ -13,7 +30,7 @@
 #include <qstring.h>
 #include "qtcompatmac.h"
 #if QT_VERSION >= 0x040000
-#include <Q3ListBox>
+#include <QListWidget>
 #else
 #include <qlistbox.h>
 #endif
@@ -21,12 +38,19 @@
 /**
  * List of directories to operate on.
  */
-class DirList : public Q3ListBox {
+class DirList : public
+#if QT_VERSION >= 0x040000
+QListWidget
+#else
+QListBox
+#endif
+{
 public:
 	/**
 	 * Constructor.
+	 * @param parent parent widget
 	 */
-	DirList(QWidget* parent = 0, const char* name = 0, Qt::WFlags f = 0);
+	DirList(QWidget* parent = 0);
 
 	/**
 	 * Destructor.
