@@ -5,6 +5,23 @@
  * \b Project: Kid3
  * \author Urs Fleisch
  * \date 17 Sep 2003
+ *
+ * Copyright (C) 2003-2007  Urs Fleisch
+ *
+ * This file is part of Kid3.
+ *
+ * Kid3 is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Kid3 is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <qstring.h>
@@ -26,7 +43,7 @@ Kid3Settings::Kid3Settings()
 		QTextStream stream(&file);
 		QString line;
 		while (!(line = stream.readLine()).isNull()) {
-			int equalPos = line.find('=');
+			int equalPos = line.QCM_indexOf('=');
 			if (equalPos > 0) {
 				m_map[line.left(equalPos)] = line.mid(equalPos + 1);
 			}
@@ -105,13 +122,19 @@ QMap<QString, QString> Kid3Settings::readMapEntry(const QString& key, const QMap
 	QMap<QString, QString> val;
 	QMap<QString, QString>::Iterator it;
 	for (it = m_map.begin(); it != m_map.end(); ++it) {
-		if (it.key().find(m_group + key) == 0) {
+		if (it.key().QCM_indexOf(m_group + key) == 0) {
 			found = true;
 			val[it.key().mid((m_group + key).length())] = it.data();
 		}
 	}
 	return found ? val : dflt;
 }
+
+bool Kid3Settings::removeEntry(const QString& key)
+{
+	m_map.erase(key);
+	return true;
+} 
 #endif
 #endif
 
