@@ -5,6 +5,23 @@
  * \b Project: Kid3
  * \author Urs Fleisch
  * \date 17 Sep 2003
+ *
+ * Copyright (C) 2003-2007  Urs Fleisch
+ *
+ * This file is part of Kid3.
+ *
+ * Kid3 is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Kid3 is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef GENERALCONFIG_H
@@ -42,6 +59,7 @@ public:
 	bool readBoolEntry(const QString& key, bool dflt = 0);
 	QStringList readListEntry(const QString& key);
 	QMap<QString, QString> readMapEntry(const QString& key, const QMap<QString, QString>& dflt);
+	bool removeEntry(const QString& key);
 private:
 	QMap<QString, QString> m_map;
 	QString m_group;
