@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2007  Urs Fleisch
+ * Copyright (C) 2006-2009  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -148,6 +148,20 @@ public:
 	 */
 	void setAdditionalTags(bool enable);
 
+	/**
+	 * Get cover art option.
+	 *
+	 * @return true if cover art are enabled.
+	 */
+	bool getCoverArt() const;
+
+	/**
+	 * Set cover art option.
+	 *
+	 * @param enable true if cover art are enabled
+	 */
+	void setCoverArt(bool enable);
+
 	/**
 	 * Set a find string from artist and album information.
 	 *
@@ -204,6 +218,13 @@ private slots:
 	 */
 	void showHelp();
 
+	/**
+	 * Display message in status bar.
+	 *
+	 * @param msg status message
+	 */
+	void showStatusMessage(const QString& msg);
+
 signals:
 	/**
 	 * Emitted when the m_trackDataVector was updated with new imported data.
@@ -232,6 +253,7 @@ private:
 	QComboBox* m_serverComboBox;
 	QLineEdit* m_cgiLineEdit;
 	QCheckBox* m_additionalTagsCheckBox;
+	QCheckBox* m_coverArtCheckBox;
 	QStatusBar* m_statusBar;
 	ImportSourceClient* m_client;
 	const Properties& m_props;
