@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2009  Urs Fleisch
+ * Copyright (C) 2003-2010  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -130,6 +130,7 @@ FormatConfig Kid3App::s_id3FormatCfg("Id3Format");
 FreedbConfig Kid3App::s_freedbCfg("Freedb");
 FreedbConfig Kid3App::s_trackTypeCfg("TrackType");
 DiscogsConfig Kid3App::s_discogsCfg("Discogs");
+AmazonConfig Kid3App::s_amazonCfg("Amazon");
 MusicBrainzConfig Kid3App::s_musicBrainzCfg("MusicBrainz");
 FilterConfig Kid3App::s_filterCfg("Filter");
 PlaylistConfig Kid3App::s_playlistCfg("Playlist");
@@ -305,6 +306,10 @@ void Kid3App::initActions()
 		    i18n("Import from &Discogs..."), this,
 		    SLOT(slotImportDiscogs()), actionCollection(),
 		    "import_discogs");
+	KCM_KAction(fileImportAmazon,
+		    i18n("Import from &Amazon..."), this,
+		    SLOT(slotImportAmazon()), actionCollection(),
+		    "import_amazon");
 	KCM_KAction(fileImportMusicBrainzRelease,
 		    i18n("Import from MusicBrainz &Release..."), this,
 		    SLOT(slotImportMusicBrainzRelease()), actionCollection(),
@@ -498,6 +503,13 @@ void Kid3App::initActions()
 		connect(fileImportDiscogs, QCM_SIGNAL_triggered,
 			this, SLOT(slotImportDiscogs()));
 	}
+	QAction* fileImportAmazon = new QAction(this);
+	if (fileImportAmazon) {
+		fileImportAmazon->setStatusTip(i18n("Import from Amazon"));
+		fileImportAmazon->QCM_setMenuText(i18n("Import from &Amazon..."));
+		connect(fileImportAmazon, QCM_SIGNAL_triggered,
+			this, SLOT(slotImportAmazon()));
+	}
 	QAction* fileImportMusicBrainzRelease = new QAction(this);
 	if (fileImportMusicBrainzRelease) {
 		fileImportMusicBrainzRelease->setStatusTip(i18n("Import from MusicBrainz Release"));
@@ -708,6 +720,7 @@ void Kid3App::initActions()
 		QCM_addAction(fileMenu, fileImportFreedb);
 		QCM_addAction(fileMenu, fileImportTrackType);
 		QCM_addAction(fileMenu, fileImportDiscogs);
+		QCM_addAction(fileMenu, fileImportAmazon);
 		QCM_addAction(fileMenu, fileImportMusicBrainzRelease);
 #ifdef HAVE_TUNEPIMP
 		QCM_addAction(fileMenu, fileImportMusicBrainz);
@@ -879,6 +892,7 @@ void Kid3App::saveOptions()
 	s_freedbCfg.writeToConfig(m_config);
 	s_trackTypeCfg.writeToConfig(m_config);
 	s_discogsCfg.writeToConfig(m_config);
+	s_amazonCfg.writeToConfig(m_config);
 	s_filterCfg.writeToConfig(m_config);
 	s_playlistCfg.writeToConfig(m_config);
 #ifdef HAVE_TUNEPIMP
@@ -930,6 +944,7 @@ void Kid3App::readOptions()
 		s_trackTypeCfg.m_server = "tracktype.org:80"; // replace default
 	}
 	s_discogsCfg.readFromConfig(m_config);
+	s_amazonCfg.readFromConfig(m_config);
 	s_filterCfg.readFromConfig(m_config);
 	s_playlistCfg.readFromConfig(m_config);
 #ifdef HAVE_TUNEPIMP
@@ -1619,7 +1634,7 @@ void Kid3App::slotHelpAbout()
 	QMessageBox::about(
 		(Kid3App*)parent(), "Kid3",
 		"Kid3 " VERSION
-		"\n(c) 2003-2009 Urs Fleisch\nufleisch@users.sourceforge.net");
+		"\n(c) 2003-2010 Urs Fleisch\nufleisch@users.sourceforge.net");
 }
 
 /**
@@ -1920,6 +1935,18 @@ void Kid3App::slotImportDiscogs()
 	}
 }
 
+/**
+ * Import from Amazon.
+ */
+void Kid3App::slotImportAmazon()
+{
+	setupImportDialog();
+	if (m_importDialog) {
+		m_importDialog->setAutoStartSubDialog(ImportDialog::ASD_Amazon);
+		execImportDialog();
+	}
+}
+
 /**
  * Import from MusicBrainz release database.
  */
@@ -2252,7 +2279,7 @@ void Kid3App::slotSettingsConfigure()
  */
 void Kid3App::slotApplyFilenameFormat()
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FileListItem* mp3file = m_view->firstFile();
 	bool no_selection = m_view->numFilesSelected() == 0;
 	while (mp3file != 0) {
@@ -2274,7 +2301,7 @@ void Kid3App::slotApplyFilenameFormat()
 void Kid3App::slotApplyId3Format()
 {
 	FrameCollection frames;
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FrameFilter fltV1(m_view->frameTableV1()->getEnabledFrameFilter(true));
 	FrameFilter fltV2(m_view->frameTableV2()->getEnabledFrameFilter(true));
 	FileListItem* mp3file = m_view->firstFile();
@@ -2434,7 +2461,7 @@ void Kid3App::slotRenameDirectory()
  */
 void Kid3App::numberTracks(int nr, bool destV1, bool destV2)
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FileListItem* mp3file = m_view->firstFileInDir();
 	bool no_selection = m_view->numFilesSelected() == 0;
 	while (mp3file != 0) {
@@ -2589,7 +2616,7 @@ void Kid3App::slotFilter()
 void Kid3App::slotConvertToId3v24()
 {
 #ifdef HAVE_TAGLIB
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FileListItem* item = m_view->firstFile();
 	while (item != 0) {
 		TaggedFile* taggedFile;
@@ -2643,7 +2670,7 @@ void Kid3App::slotConvertToId3v24()
 void Kid3App::slotConvertToId3v23()
 {
 #if defined HAVE_TAGLIB && defined HAVE_ID3LIB
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FileListItem* item = m_view->firstFile();
 	while (item != 0) {
 		TaggedFile* taggedFile;
@@ -2840,11 +2867,8 @@ void Kid3App::updateModificationState()
 
 /**
  * Update files of current selection.
- *
- * @param onlyIfSingleFileSelected if true, the selection is only updated
- *                                 if a single file is selected
  */
-void Kid3App::updateCurrentSelection(bool onlyIfSingleFileSelected)
+void Kid3App::updateCurrentSelection()
 {
 	int numFiles = 0;
 	FileListItem* mp3file = m_view->firstFile();
@@ -2857,9 +2881,6 @@ void Kid3App::updateCurrentSelection(bool onlyIfSingleFileSelected)
 		}
 		mp3file = m_view->nextFile();
 	}
-	if (onlyIfSingleFileSelected && numFiles != 1) {
-		return;
-	}
 	if (numFiles > 0) {
 		m_view->frameTableV1()->tableToFrames(numFiles > 1);
 		m_view->frameTableV2()->tableToFrames(numFiles > 1);
@@ -2887,10 +2908,9 @@ void Kid3App::updateCurrentSelection(bool onlyIfSingleFileSelected)
 void Kid3App::updateGuiControls()
 {
 	FileListItem* mp3file = m_view->firstFile();
-	FileListItem* singleItem = 0;
 	TaggedFile* single_v2_file = 0;
-	TaggedFile* firstMp3File = 0;
-	int num_files_selected = 0;
+	int num_v1_selected = 0;
+	int num_v2_selected = 0;
 	bool tagV1Supported = false;
 
 #if QT_VERSION >= 0x040000
@@ -2914,28 +2934,29 @@ void Kid3App::updateGuiControls()
 				taggedFile = readWithTagLibIfId3V24(mp3file, taggedFile);
 #endif
 
-				if (num_files_selected == 0) {
-					taggedFile->getAllFramesV1(m_view->frameTableV1()->frames());
+				if (taggedFile->isTagV1Supported()) {
+					if (num_v1_selected == 0) {
+						taggedFile->getAllFramesV1(m_view->frameTableV1()->frames());
+					}
+					else {
+						FrameCollection fileFrames;
+						taggedFile->getAllFramesV1(fileFrames);
+						m_view->frameTableV1()->frames().filterDifferent(fileFrames);
+					}
+					++num_v1_selected;
+					tagV1Supported = true;
+				}
+				if (num_v2_selected == 0) {
 					taggedFile->getAllFramesV2(m_view->frameTableV2()->frames());
 					single_v2_file = taggedFile;
-					singleItem = mp3file;
-					firstMp3File = taggedFile;
 				}
 				else {
 					FrameCollection fileFrames;
-					taggedFile->getAllFramesV1(fileFrames);
-					m_view->frameTableV1()->frames().filterDifferent(fileFrames);
-					fileFrames.clear();
 					taggedFile->getAllFramesV2(fileFrames);
 					m_view->frameTableV2()->frames().filterDifferent(fileFrames);
 					single_v2_file = 0;
-					singleItem = 0;
-				}
-				++num_files_selected;
-
-				if (taggedFile->isTagV1Supported()) {
-					tagV1Supported = true;
 				}
+				++num_v2_selected;
 			}
 		}
 		else {
@@ -2966,7 +2987,9 @@ void Kid3App::updateGuiControls()
 		}
 	}
 	else {
-		m_view->setFilenameEditEnabled(false);
+		if (num_v2_selected > 1) {
+			m_view->setFilenameEditEnabled(false);
+		}
 		m_view->setDetailInfo(info);
 		m_view->setTagFormatV1(QString::null);
 		m_view->setTagFormatV2(QString::null);
@@ -2991,13 +3014,13 @@ void Kid3App::updateGuiControls()
 			m_view->setPictureData(PictureFrame::getData(*it, data) ? &data : 0);
 		}
 	}
-	m_view->frameTableV1()->setAllCheckBoxes(num_files_selected == 1);
+	m_view->frameTableV1()->setAllCheckBoxes(num_v1_selected == 1);
 	m_view->frameTableV1()->framesToTable();
-	m_view->frameTableV2()->setAllCheckBoxes(num_files_selected == 1);
+	m_view->frameTableV2()->setAllCheckBoxes(num_v2_selected == 1);
 	m_view->frameTableV2()->framesToTable();
 	updateModificationState();
 
-	if (num_files_selected == 0) {
+	if (num_v1_selected == 0 && num_v2_selected == 0) {
 		tagV1Supported = true;
 	}
 	m_view->enableControlsV1(tagV1Supported);
@@ -3020,7 +3043,7 @@ void Kid3App::fileSelected()
  */
 void Kid3App::copyTagsV1()
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	m_copyTags = m_view->frameTableV1()->frames().copyEnabledFrames(
 		m_view->frameTableV1()->getEnabledFrameFilter(true));
 }
@@ -3030,7 +3053,7 @@ void Kid3App::copyTagsV1()
  */
 void Kid3App::copyTagsV2()
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	m_copyTags = m_view->frameTableV2()->frames().copyEnabledFrames(
 		m_view->frameTableV2()->getEnabledFrameFilter(true));
 }
@@ -3040,7 +3063,7 @@ void Kid3App::copyTagsV2()
  */
 void Kid3App::pasteTagsV1()
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FrameCollection frames(m_copyTags.copyEnabledFrames(
 													 m_view->frameTableV1()->getEnabledFrameFilter(true)));
 	formatFramesIfEnabled(frames);
@@ -3060,7 +3083,7 @@ void Kid3App::pasteTagsV1()
  */
 void Kid3App::pasteTagsV2()
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FrameCollection frames(m_copyTags.copyEnabledFrames(
 													 m_view->frameTableV2()->getEnabledFrameFilter(true)));
 	formatFramesIfEnabled(frames);
@@ -3082,7 +3105,7 @@ void Kid3App::pasteTagsV2()
  */
 void Kid3App::getTagsFromFilenameV1()
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FrameCollection frames;
 	FileListItem* mp3file = m_view->firstFile();
 	bool multiselect = m_view->numFilesSelected() > 1;
@@ -3094,7 +3117,8 @@ void Kid3App::getTagsFromFilenameV1()
 					m_view->getFilename());
 			}
 			mp3file->getFile()->getAllFramesV1(frames);
-			mp3file->getFile()->getTagsFromFilename(frames, m_view->getFilenameFormat());
+			mp3file->getFile()->getTagsFromFilename(frames,
+			                                        m_view->getFromFilenameFormat());
 			frames.removeDisabledFrames(flt);
 			formatFramesIfEnabled(frames);
 			mp3file->getFile()->setFramesV1(frames);
@@ -3112,7 +3136,7 @@ void Kid3App::getTagsFromFilenameV1()
  */
 void Kid3App::getTagsFromFilenameV2()
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FrameCollection frames;
 	FileListItem* mp3file = m_view->firstFile();
 	bool multiselect = m_view->numFilesSelected() > 1;
@@ -3124,7 +3148,8 @@ void Kid3App::getTagsFromFilenameV2()
 					m_view->getFilename());
 			}
 			mp3file->getFile()->getAllFramesV2(frames);
-			mp3file->getFile()->getTagsFromFilename(frames, m_view->getFilenameFormat());
+			mp3file->getFile()->getTagsFromFilename(frames,
+			                                        m_view->getFromFilenameFormat());
 			frames.removeDisabledFrames(flt);
 			formatFramesIfEnabled(frames);
 			mp3file->getFile()->setFramesV2(frames);
@@ -3177,7 +3202,7 @@ void Kid3App::getFilenameFromTags(int tag_version)
  */
 void Kid3App::copyV1ToV2()
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FrameCollection frames;
 	FrameFilter flt(m_view->frameTableV2()->getEnabledFrameFilter(true));
 	FileListItem* mp3file = m_view->firstFile();
@@ -3199,7 +3224,7 @@ void Kid3App::copyV1ToV2()
  */
 void Kid3App::copyV2ToV1()
 {
-	updateCurrentSelection(true);
+	updateCurrentSelection();
 	FrameCollection frames;
 	FrameFilter flt(m_view->frameTableV1()->getEnabledFrameFilter(true));
 	FileListItem* mp3file = m_view->firstFile();
