@@ -56,6 +56,7 @@ typedef QMainWindow Kid3AppBaseClass;
 #include "miscconfig.h"
 #include "freedbconfig.h"
 #include "discogsconfig.h"
+#include "amazonconfig.h"
 #include "musicbrainzconfig.h"
 #include "filterconfig.h"
 #include "playlistconfig.h"
@@ -117,11 +118,8 @@ public:
 
 	/**
 	 * Update files of current selection.
-	 *
-	 * @param onlyIfSingleFileSelected if true, the selection is only updated
-	 *                                 if a single file is selected
 	 */
-	void updateCurrentSelection(bool onlyIfSingleFileSelected = false);
+	void updateCurrentSelection();
 
 	/**
 	 * Copy tags 1 into copy buffer.
@@ -306,6 +304,8 @@ public:
 	static FreedbConfig s_trackTypeCfg;
 	/** Discogs configuration */
 	static DiscogsConfig s_discogsCfg;
+	/** Amazon configuration */
+	static AmazonConfig s_amazonCfg;
 	/** MusicBrainz configuration */
 	static MusicBrainzConfig s_musicBrainzCfg;
 	/** Filter configuration */
@@ -540,6 +540,11 @@ public slots:
 	 */
 	void slotImportDiscogs();
 
+	/**
+	 * Import from Amazon.
+	 */
+	void slotImportAmazon();
+
 	/**
 	 * Import from MusicBrainz release database.
 	 */
