@@ -58,6 +58,12 @@ public:
 		TE_UTF8
 	};
 
+	/** Name for Vorbis picture. */
+	enum VorbisPictureName {
+		VP_METADATA_BLOCK_PICTURE,
+		VP_COVERART
+	};
+
 	/**
 	 * External command in context menu.
 	 */
@@ -168,12 +174,22 @@ public:
 	bool m_markChanges;
 	/** field name used for Vorbis comment entries */
 	QString m_commentName;
+	/** index of field name used for Vorbis picture entries */
+	int m_pictureNameItem;
 	/** filter of file names to be opened */
 	QString m_nameFilter;
 	/** filename format */
 	QString m_formatText;
 	/** index of filename format selected */
 	int m_formatItem;
+	/** filename formats */
+	QStringList m_formatItems;
+	/** from filename format */
+	QString m_formatFromFilenameText;
+	/** index of from filename format selected */
+	int m_formatFromFilenameItem;
+	/** from filename formats */
+	QStringList m_formatFromFilenameItems;
 	/** directory name format */
 	QString m_dirFormatText;
 	/** index of directory name format selected */
