@@ -377,8 +377,10 @@ protected:
 	 *
 	 * @param name name
 	 * @param value value, "" to remove, QString::null to do nothing
+	 * @param type frame type
 	 */
-	void setTextField(const QString& name, const QString& value);
+	void setTextField(const QString& name, const QString& value,
+	                  Frame::Type type);
 
 	/** Comments of this file. */
 	CommentList m_comments;
